/*
 * This file is part of essential (http://essential.craftforge.net).
 *
 *     Essential is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU Lesser Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     Essential is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Copyright (c) 2011 Christian Bick.
 */

package net.craftforge.essential.context.server;

import com.sun.net.httpserver.HttpExchange;
import com.sun.net.httpserver.HttpHandler;
import net.craftforge.essential.controller.*;

import java.io.IOException;

/**
 * A lightweight HTTP handler context implementation for forwarding an <code>HttpExchange</code>
 * to the framework.
 *
 * @author Christian Bick
 * @since 19.06.11
 */
public class EssentialHttpHandler implements HttpHandler {

    private String context;
    private String packagePath;

    /**
     * Creates an HTTP Handler.
     *
     * @param context The server context
     * @param packagePath The controller's package path containing resource classes
     */
    public EssentialHttpHandler(String context, String packagePath) {
        this.context = context;
        this.packagePath = packagePath;
    }

    /**
     * Handles an incoming request using the HTTP exchange as source of request and target of response
     * data.
     *
     * @param httpExchange The HTTP exchange
     * @throws IOException if data input or output resources cannot be acquired
     */
    public void handle(HttpExchange httpExchange) throws IOException {
        try {
            Request req = new HttpServerRequestImpl(context, httpExchange);
            Response resp = new HttpServerResponseImpl(httpExchange);

            Configuration config = new Configuration();
            Controller.getInstance(packagePath, config).perform(req, resp);
        } catch (ControllerException e) {
            e.printStackTrace();
            httpExchange.sendResponseHeaders(e.getHttpStatusCode().getCode(), -1);
        } catch (Exception e) {
            e.printStackTrace();
            httpExchange.sendResponseHeaders(500, -1);
        }
        httpExchange.close();
    }
}
