/*
 * This file is part of essential (http://essential.craftforge.net).
 *
 *     Essential is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU Lesser Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     Essential is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Copyright (c) 2011 Christian Bick.
 */

package net.craftforge.essential.context.server;

import com.sun.net.httpserver.HttpServer;

import java.io.IOException;
import java.net.InetSocketAddress;
import java.net.URL;
import java.util.concurrent.Executors;

/**
 * A lightweight http server as basis for handling HTTP requests being forwarded
 * to the framework.
 *
 * @author Christian Bick
 * @since 19.06.11
 */
public class EssentialHttpServer {

    private HttpServer server;

    /**
     * Creates a lightweight http server.
     *
     * @param baseUrl The server address including context path (e.g. 'http://api.craftforge.net')
     * @param packagePath The controller's package path containing resource classes
     * @throws IOException if server failed to initializes due to used or restricted resources (e.g. used port)
     */
    public  EssentialHttpServer(String baseUrl, String packagePath) throws IOException {
        URL url = new URL(baseUrl);
        String address = url.getHost();
        int port = url.getPort();
        String context = url.getPath();
        InetSocketAddress socket = new InetSocketAddress(address, port);
        EssentialHttpHandler handler = new EssentialHttpHandler(context, packagePath);
        server = HttpServer.create(socket, 0);
        server.createContext(context, handler);
        server.setExecutor(Executors.newCachedThreadPool());
    }

    /**
     * Starts the server.
     */
    public void start() {
        server.start();
        System.out.println("Essential HTTP Server started: " + server.getAddress());
    }

    /**
     * Stops the server.
     */
    public void stop() {
        server.stop(0);
        System.out.println("Essential HTTP Server stopped.");
    }
}
