/*
 * This file is part of essential (http://essential.craftforge.net).
 *
 *     Essential is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU Lesser Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     Essential is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Copyright (c) 2011 Christian Bick.
 */

package net.craftforge.essential.testsuite;

import net.craftforge.essential.context.server.EssentialHttpServer;
import net.craftforge.essential.testsuite.NetworkClientTest;
import net.craftforge.essential.testsuite.TestValues;
import org.junit.After;
import org.junit.Before;

/**
 * @author Christian Bick
 * @since 01.09.11
 */
public abstract class HttpServerTest extends NetworkClientTest {

    private EssentialHttpServer server;

    private String baseUrl;
    private String packagePath;

    public HttpServerTest() {
        this(TestValues.DEFAULT_BASE_URL, TestValues.DEFAULT_PACKAGE_PATH);
    }

    public HttpServerTest(String baseUrl, String packagePath) {
        super(baseUrl);
        this.baseUrl = baseUrl;
        this.packagePath = packagePath;
    }

    /**
     * {@inheritDoc}
     * Starts up an own implementation of a lightweight server using a custom handler
     * which invokes an Essential controller.
     *
     * @throws Exception if an unexpected exception occurs
     */
    @Before
    public void setUp() throws Exception {
        server = new EssentialHttpServer(baseUrl, packagePath);
        server.start();
    }

    /**
     * Stops the lightweight server.
     *
     * @throws Exception if an unexpected exception occurs
     */
    @After
    public void tearDown() throws Exception {
        server.stop();
    }


}
